.. -*- coding: utf-8 -*-

What's next?
------------

In this tutorial, we have seen that you can, right after the installation of
|cubicweb|, build a web application in a few minutes by defining a data model as
assembling cubes. You get a working application that you can then customize there
and there while keeping something that works. This is important in agile
development practices, you can right from the start of the project show things
to customer and so take the right decision early in the process.

The next steps will be to discover hooks, security, data sources, digging deeper
into view writing and interface customisation... Yet a lot of fun stuff to
discover! You will find more `tutorials and howtos`_ in the blog published on the
CubicWeb.org website.

.. _`tutorials and howtos`: http://www.cubicweb.org/view?rql=Any+X+ORDERBY+D+DESC+WHERE+X+is+BlogEntry%2C+T+tags+X%2C+T+name+IN+%28%22tutorial%22%2C+%22howto%22%29%2C+X+creation_date+D
